#########################
Aldryn Commandline Client
#########################

|PyPI Version| |PyPI Downloads| |Wheel Support| |License|

**********
Installing
**********

``pip install aldryn-client``


****************
Using the client
****************

for more information see http://docs.aldryn.com/en/latest/tutorial/commandline/installation.html

.. |PyPI Version| image:: https://img.shields.io/pypi/v/aldryn-client.svg
   :target: https://pypi.python.org/pypi/aldryn-client
.. |PyPI Downloads| image:: https://img.shields.io/pypi/dm/aldryn-client.svg
   :target: https://pypi.python.org/pypi/aldryn-client
.. |Wheel Support| image:: https://img.shields.io/pypi/wheel/aldryn-client.svg
   :target: https://pypi.python.org/pypi/aldryn-client
.. |License| image:: https://img.shields.io/pypi/l/aldryn-client.svg
   :target: https://pypi.python.org/pypi/aldryn-client
